pilas.actores.mapatiled

Package pilas :: Package actores :: Module mapatiled |
[hide private]
[frames] | no frames]

# Module mapatiled

source code

Classes | [hide private]
| MapaTiled Representa mapas creados a partir de imagenes mas pequeñas.
| XmlNode Representa un nodo XML.

Functions | [hide private]
makeRootNode(xmlFileName) Genera un nodo XML dado un archivo. | source code

Variables | [hide private]
| __package__ = ``'``pilas.actores``'``

Function Details | [hide private]

### makeRootNode(xmlFileName) | source code
Genera un nodo XML dado un archivo. :param xmlFileName: El nombre del archivo .xml